function bdlc:fetchUserGear(unit, itemLink)
	local name, link, quality, iLevel, reqLevel, class, subclass, maxStack, equipSlot, texture, vendorPrice = GetItemInfo(itemLink)
	
	local found_tier = false
	for k, v in pairs(bdlc.tier_names) do
		if (strfind(name, k)) then found_tier = true end
	end
	
	if (found_tier) then
		if (strfind(name, "Helm")) then
			equipSlot = "INVTYPE_HEAD"
		elseif (strfind(name, "Shoulders")) then
			equipSlot = "INVTYPE_SHOULDER"
		elseif (strfind(name, "Leggings")) then
			equipSlot = "INVTYPE_LEGS"
		elseif (strfind(name, "Chest")) then
			equipSlot = "INVTYPE_CHEST"
		elseif (strfind(name, "Gauntlets")) then
			equipSlot = "INVTYPE_HAND"
		elseif (strfind(name, "Badge")) then
			equipSlot = "INVTYPE_TRINKET"
		end
	end
	
	local slotID = 0;
	if (equipSlot == "INVTYPE_HEAD") then slotID = 1 end
	if (equipSlot == "INVTYPE_NECK") then slotID = 2 end
	if (equipSlot == "INVTYPE_SHOULDER") then slotID = 3 end
	if (equipSlot == "INVTYPE_BODY") then slotID = 4 end
	if (equipSlot == "INVTYPE_CHEST") then slotID = 5 end
	if (equipSlot == "INVTYPE_WAIST") then slotID = 6 end
	if (equipSlot == "INVTYPE_LEGS") then slotID = 7 end
	if (equipSlot == "INVTYPE_FEET") then slotID = 8 end
	if (equipSlot == "INVTYPE_WRIST") then slotID = 9 end
	if (equipSlot == "INVTYPE_HAND") then slotID = 10 end
	if (equipSlot == "INVTYPE_BACK") then slotID = 15 end
	if (equipSlot == "INVTYPE_CLOAK") then slotID = 15 end
	if (equipSlot == "INVTYPE_OFFHAND") then slotID = 17 end
	if (equipSlot == "INVTYPE_RANGED") then slotID = 18 end
	
	local itemLink1 = GetInventoryItemLink(unit, slotID)
	local itemLink2 = 0

	if (equipSlot == "INVTYPE_FINGER") then 
		itemLink1 = GetInventoryItemLink(unit, 11)
		itemLink2 = GetInventoryItemLink(unit, 12)
	end
	if (equipSlot == "INVTYPE_TRINKET") then
		itemLink1 = GetInventoryItemLink(unit, 13)
		itemLink2 = GetInventoryItemLink(unit, 14)
	end
	if (equipSlot == "INVTYPE_WEAPON" or equipSlot == "INVTYPE_2HWEAPON" or equipSlot == "INVTYPE_SHIELD" or equipSlot == "INVTYPE_HOLDABLE" or equipSlot == "INVTYPE_RANGEDRIGHT" or equipSlot == "INVTYPE_RANGED") then
		itemLink1 = GetInventoryItemLink(unit, 16)
		itemLink2 = GetInventoryItemLink(unit, 17)
	end
	if (not itemLink1) then
		itemLink1 = 0
	end
	if (not itemLink2) then
		itemLink2 = 0
	end
	
	return itemLink1, itemLink2
end

function bdlc:repositionFrames()
	-- Loop through tabs and entries, sort by want level
	local lasttab = nil
	for t = 1, #bdlc.frames.tabs do
		local currenttab = bdlc.frames.tabs[t]
		local lastentry = nil
		local newtable = {}

		table.sort(bdlc.frames.entries[t], function(a, b)
			a.rankIndex = a.rankIndex or 0
			b.rankIndex = b.rankIndex or 0
			
			a.wantLevel = a.wantLevel or 0
			b.wantLevel = b.wantLevel or 0
			if a.rankIndex ~= b.rankIndex then
				return a.rankIndex > b.rankIndex
			end
			if a.wantLevel ~= b.wantLevel then
				return a.wantLevel < b.wantLevel
			end
			return a.name:GetText() > b.name:GetText()
		end)
		
		for e = 1, #bdlc.frames.entries[t] do
			local currententry = bdlc.frames.entries[t][e]
			if (currententry.active) then
				if (lastentry) then
					currententry:SetPoint("TOPLEFT", lastentry, "BOTTOMLEFT", 0, -1)
				else
					currententry:SetPoint("TOPLEFT", currenttab.table.content, "TOPLEFT", 2, 0)
				end
				lastentry = currententry
			end
		end
		
		if (currenttab.active) then
			if (lasttab) then
				currenttab:SetPoint("TOPRIGHT", lasttab, "BOTTOMRIGHT", 0, 2)
			else
				currenttab:SetPoint("TOPRIGHT", lcVoteFrame.tabs, "TOPRIGHT", 2, 0)
			end
			lasttab = currenttab
		end
	end
	-- Loop through rolls
	local lastroll = nil
	for r = 1, #bdlc.frames.rolls do
		local currentroll = bdlc.frames.rolls[r]
		
		if (currentroll.active) then
			if (lastroll) then
				currentroll:SetPoint("TOPLEFT", lastroll, "BOTTOMLEFT", 0, 1)
			else
				currentroll:SetPoint("TOPLEFT", rollFrame, "TOPLEFT", 0, 0)
			end
			lastroll = currentroll
		end
	end
	if (not lastroll) then
		rollFrame:Hide()
	end
	if (not lasttab) then
		lcVoteFrame:Hide()
	end
	
	-- if no tab is selected, select the first tab
	local tabselect = nil
	for tabs = 1, #bdlc.frames["tabs"] do
		if (bdlc.frames["tabs"][tabs]:GetAlpha() == 1) then
			tabselect = true
		end
	end
	
	if (not tabselect) then
		local currenttab = nil
		for i = 1, #bdlc.frames.tabs do
			if (not currenttab and bdlc.frames.tabs[i].active) then
				currenttab = bdlc.frames.tabs[i]
				currenttab:SetAlpha(1)
				currenttab.table:Show()
				currenttab.icon:SetDesaturated(false)
			end
		end
	end
end

function bdlc:CreateFrames()
	local name = UnitName("player")
	local player_realm = GetRealmName()
	local local_player = name.."-"..player_realm
	debug("building frames")
	-------------------------------------------------------
	--	Create all the necessary frames now, use them forever. 
	-------------------------------------------------------
	local bdlc_font_small = CreateFont("BDLC_FONT_SMALL")
	bdlc_font_small:SetFont("Interface\\Addons\\BDLC\\font.ttf", 12)
	bdlc_font_small:SetShadowColor(0, 0, 0)
	bdlc_font_small:SetShadowOffset(1, -1)
	local bdlc_font = CreateFont("BDLC_FONT")
	bdlc_font:SetFont("Interface\\Addons\\BDLC\\font.ttf", 13)
	bdlc_font:SetShadowColor(0, 0, 0)
	bdlc_font:SetShadowOffset(1, -1)
	local bdlc_font_large = CreateFont("BDLC_FONT_LARGE")
	bdlc_font_large:SetFont("Interface\\Addons\\BDLC\\font.ttf", 14)
	bdlc_font_large:SetShadowColor(0, 0, 0)
	bdlc_font_large:SetShadowOffset(1, -1)
	local normal_text = CreateFont("bdlc_button")
	normal_text:SetFont("Interface\\Addons\\BDLC\\font.ttf", 13)
	normal_text:SetTextColor(1,1,1,1)
	normal_text:SetShadowColor(0, 0, 0)
	normal_text:SetShadowOffset(1, -1)
	normal_text:SetJustifyH("RIGHT")
	
	--Vote Window
	lcVoteFrame = CreateFrame('frame', 'BDLC', UIParent)
	skinBackdrop(lcVoteFrame, .1,.1,.1,.8);
	lcVoteFrame:EnableMouse(true);
	--lcVoteFrame:SetResizable(true);
	lcVoteFrame:SetMovable(true);
	lcVoteFrame:SetUserPlaced(true);
	lcVoteFrame:SetFrameStrata("DIALOG");
	lcVoteFrame:SetFrameLevel(1);
	lcVoteFrame:SetClampedToScreen(true);
	--lcVoteFrame:SetMinResize(600, 400);
	lcVoteFrame:SetSize(600, 400);
	lcVoteFrame:SetPoint("CENTER");
	lcVoteFrame:Hide()
	
	-- Header
	lcVoteFrame.header = CreateFrame("frame", nil, lcVoteFrame);
	lcVoteFrame.header:EnableMouse(true);
	lcVoteFrame.header:RegisterForDrag("LeftButton","RightButton")
	lcVoteFrame.header:SetScript("OnDragStart", function(self) lcVoteFrame:StartMoving() end)
	lcVoteFrame.header:SetScript("OnDragStop", function(self)  lcVoteFrame:StopMovingOrSizing() end)
	
	lcVoteFrame.header.close = CreateFrame("Button", nil, lcVoteFrame.header)
	lcVoteFrame.header.close:SetPoint("RIGHT", lcVoteFrame.header, "RIGHT", -4, 0)
	lcVoteFrame.header.close:SetText("x")
	skinButton(lcVoteFrame.header.close,true,"red")
	lcVoteFrame.header.close:SetScript("OnClick", function()
		lcVoteFrame:Hide()
	end)
	-- lcVoteFrame.header.close:SetScript("OnMouseUp", function()
	-- end)
	-- lcVoteFrame.header.close:SetScript("OnEnter", function()
		-- lcVoteFrame.header.close:SetBackdropColor(.5,.1,.1,1)
	-- end)
	-- lcVoteFrame.header.close:SetScript("OnLeave", function()
		-- lcVoteFrame.header.close:SetBackdropColor(.5,.1,.1,.5)
	-- end)
	
	lcVoteFrame.header:SetPoint("TOPLEFT", lcVoteFrame, "TOPLEFT")
	lcVoteFrame.header:SetPoint("BOTTOMRIGHT", lcVoteFrame, "TOPRIGHT", 0, -24)
	lcVoteFrame.header:SetBackdrop({bgFile = "Interface\\Buttons\\WHITE8x8", edgeSize = 0})
	lcVoteFrame.header:SetBackdropColor(0,0,0,.3)
	
	lcVoteFrame.header.text = lcVoteFrame.header:CreateFontString(nil, "OVERLAY", "BDLC_FONT_LARGE")
	lcVoteFrame.header.text:SetText("|cff3399FFBig Dumb Loot Council|r")
	lcVoteFrame.header.text:SetPoint("CENTER", lcVoteFrame.header, "CENTER")
	
	-- Rolls
	rollFrame = CreateFrame('frame', "BDLC Roll Window", bdlc)
	rollFrame:SetSize(418, 1)
	rollFrame:SetPoint("CENTER", UIParent, "CENTER", 600, 0)
	rollFrame:EnableMouse(true)
	rollFrame:SetMovable(true);
	rollFrame:SetUserPlaced(true);
	rollFrame:SetFrameStrata("FULLSCREEN");
	rollFrame:SetFrameLevel(10)
	rollFrame:SetClampedToScreen(true);
	rollFrame:RegisterForDrag("LeftButton","RightButton")
	rollFrame:SetScript("OnDragStart", function(self) rollFrame:StartMoving() end)
	rollFrame:SetScript("OnDragStop", function(self) rollFrame:StopMovingOrSizing() end)
	rollFrame:Hide()
	--[[rollFrame.status = CreateFrame("StatusBar", nil, rollFrame)
	rollFrame.status:SetMinMaxValues(0, 60)
	rollFrame.status:SetStatusBarTexture(bdlc.config.flat)
	rollFrame.status:SetAllPoints(rollFrame)
	rollFrame.status:SetStatusBarColor(.2, .6, .0)
	rollFrame.status:SetValue(0)
	local total = 0
	rollFrame.status:SetScript("OnUpdate", function(self, elapsed)
		if (rollFrame.status:GetValue() > 0) then
			total = total + elapsed
			if (total > .1) then
				total = 0
				rollFrame.status:SetValue(rollFrame.status:GetValue() - 0.1)
			end
		end
	end)
	rollFrame:SetScript("OnShow", function()
		rollFrame.status:SetValue(60)
	end)
	rollFrame:SetScript("OnHide", function()
		rollFrame.status:SetValue(0)
	end)--]]

	-- Create roll children
	for i = 1, 10 do
		local roll = CreateFrame("frame", nil, rollFrame);
		roll:SetPoint("TOPLEFT", rollFrame, "TOPLEFT", 0, -(59*(i-1)))
		roll:SetSize(rollFrame:GetWidth(), 60);
		roll.itemLink = 0
		roll.active = false
		roll.notes = "";
		roll:Hide()
		roll:EnableMouse(true)
		roll:SetMovable(true);
		roll:SetClampedToScreen(true);
		roll:RegisterForDrag("LeftButton","RightButton")
		roll:SetScript("OnDragStart", function(self) rollFrame:StartMoving() end)
		roll:SetScript("OnDragStop", function(self) rollFrame:StopMovingOrSizing() end)
		skinBackdrop(roll, .2, .2, .2, .9)
		
		-- Loot item info/hover
		roll.item = CreateFrame("frame", nil, roll);
		roll.item:SetAllPoints(roll)
		roll.item:SetFrameStrata("FULLSCREEN_DIALOG")
		roll.item:SetFrameLevel(4)
		roll.item:EnableMouse(true)
		roll.item:SetMovable(true);
		roll.item:SetClampedToScreen(true);
		roll.item:RegisterForDrag("LeftButton","RightButton")
		roll.item:SetScript("OnDragStart", function(self) rollFrame:StartMoving() end)
		roll.item:SetScript("OnDragStop", function(self) rollFrame:StopMovingOrSizing() end)

		roll.item.icon = CreateFrame("frame", nil, roll)
		roll.item.icon:SetSize(50, 50)
		roll.item.icon:SetPoint("TOPLEFT", roll, "TOPLEFT", 5, -5)
		skinBackdrop(roll.item.icon, 0,0,0,.8);
		
		roll.item.icon.tex = roll.item.icon:CreateTexture(nil, "OVERLAY")
		roll.item.icon.tex:SetTexCoord(0.08, 0.92, 0.08, 0.92)
		roll.item.icon.tex:SetDrawLayer('ARTWORK')
		roll.item.icon.tex:SetTexture(nil)
		roll.item.icon.tex:SetPoint("TOPLEFT", roll.item.icon, "TOPLEFT", 2, -2)
		roll.item.icon.tex:SetPoint("BOTTOMRIGHT", roll.item.icon, "BOTTOMRIGHT", -2, 2)
		
		roll.item.item_text = roll:CreateFontString(nil, "ARTWORK","BDLC_FONT_LARGE")
		roll.item.item_text:SetText("item name")
		roll.item.item_text:SetPoint("TOPLEFT", roll, "TOPLEFT", 60, -8)
		roll.item.item_text:SetJustifyH("LEFT")
		
		
		roll.item.num_items = roll:CreateFontString(nil, "OVERLAY","BDLC_FONT")
		roll.item.num_items:SetText("x1")
		roll.item.num_items:SetPoint("LEFT", roll.item.item_text, "RIGHT", 6, 0)
		roll.item.num_items:SetJustifyH("LEFT")
		
		roll.item.item_ilvl = roll:CreateFontString(nil, "OVERLAY", "BDLC_FONT_SMALL")
		roll.item.item_ilvl:SetText("ilvl: ")
		roll.item.item_ilvl:SetPoint("TOPRIGHT", roll, "TOPRIGHT", -5, -10)
		roll.item.item_ilvl:SetJustifyH("RIGHT")
		
		-- Loot Buttons
		roll.buttons = CreateFrame("frame", nil, roll);
		roll.buttons:SetPoint("BOTTOMLEFT", roll, "BOTTOMLEFT", 50, 0);
		roll.buttons:SetPoint("TOPRIGHT", roll, "BOTTOMRIGHT", 0, 40);
		roll.buttons:EnableMouse(1)
		roll.buttons:SetFrameStrata("FULLSCREEN_DIALOG")
		roll.buttons:SetFrameLevel(5)
		
		roll.buttons.submit = function(wantLevel)
			local itemLink1, itemLink2 = bdlc:fetchUserGear("player", roll.itemLink)
			
			local itemString = string.match(roll.itemLink, "item[%-?%d:]+")
			local itemType, itemID, enchant, gem1, gem2, gem3, gem4, suffixID, uniqueID, level, upgradeId, instanceDifficultyID, numBonusIDs, bonusID1, bonusID2  = string.split(":", itemString)
			bonusID1 = bonusID1 or 0
			bonusID2 = bonusID2 or 0
			local itemUID = itemID..":"..numBonusIDs..":"..bonusID1..":"..bonusID2
	
			SendAddonMessage(bdlc.message_prefix, "addUserWant><"..itemUID.."><"..local_player.."><"..wantLevel.."><"..itemLink1.."><"..itemLink2, "RAID");
			if (string.len(roll.notes) > 0) then
				SendAddonMessage(bdlc.message_prefix, "addUserNotes><"..itemUID.."><"..local_player.."><"..roll.notes, "RAID");
			end
			roll.itemLink = 0
			roll.active = false
			roll.notes = ""
			roll.buttons.notes:SetText("")
			roll.buttons.notes:Hide()
			roll:Hide()
			bdlc:repositionFrames()
		end
		
		roll.buttons.main = CreateFrame("Button", nil, roll.buttons)
		roll.buttons.main:SetPoint("LEFT", roll.buttons, "LEFT", 8, 0)
		roll.buttons.main:SetText("Mainspec")
		skinButton(roll.buttons.main)
		roll.buttons.main:SetScript("OnClick", function() roll.buttons.submit(1) end)
		
		roll.buttons.minor = CreateFrame("Button", nil, roll.buttons)
		roll.buttons.minor:SetPoint("LEFT", roll.buttons.main, "RIGHT", 1, 0)
		roll.buttons.minor:SetText("Minor Up")
		skinButton(roll.buttons.minor)
		roll.buttons.minor:SetScript("OnClick", function() roll.buttons.submit(2) end)
		
		roll.buttons.off = CreateFrame("Button", nil, roll.buttons)
		roll.buttons.off:SetPoint("LEFT", roll.buttons.minor, "RIGHT", 1, 0)
		roll.buttons.off:SetText("Offspec")
		skinButton(roll.buttons.off)
		roll.buttons.off:SetScript("OnClick", function() roll.buttons.submit(3) end)
		
		roll.buttons.reroll = CreateFrame("Button", nil, roll.buttons)
		roll.buttons.reroll:SetPoint("LEFT", roll.buttons.off, "RIGHT", 1, 0)
		roll.buttons.reroll:SetText("Reroll")
		skinButton(roll.buttons.reroll)
		roll.buttons.reroll:SetScript("OnClick", function() roll.buttons.submit(4) end)
		
		roll.buttons.xmog = CreateFrame("Button", nil, roll.buttons)
		roll.buttons.xmog:SetPoint("LEFT", roll.buttons.reroll, "RIGHT", 1, 0)
		roll.buttons.xmog:SetText("Transmog")
		skinButton(roll.buttons.xmog)
		roll.buttons.xmog:SetScript("OnClick", function() roll.buttons.submit(5) end)
		
		roll.buttons.note = CreateFrame("Button", nil, roll.buttons)
		roll.buttons.note:SetSize(40, 25)
		roll.buttons.note:SetPoint("LEFT", roll.buttons.xmog, "RIGHT", 1, 0)
		roll.buttons.note:SetText("Note")
		skinButton(roll.buttons.note,false,"blue")
		roll.buttons.note:SetScript("OnClick", function()
			roll.buttons.notes:Show()
			roll.buttons.notes:SetFocus()
			
		end)
		
		roll.buttons.pass = CreateFrame("Button", nil, roll.buttons)
		roll.buttons.pass:SetSize(42, 25)
		roll.buttons.pass:SetPoint("LEFT", roll.buttons.note, "RIGHT", 1, 0)
		roll.buttons.pass:SetText("Pass")
		skinButton(roll.buttons.pass,false,"red")
		roll.buttons.pass:SetScript("OnClick", function()
			SendAddonMessage(bdlc.message_prefix, "removeUserConsidering><"..roll.itemLink.."><"..local_player, "RAID");
			roll.itemLink = 0
			roll.active = false
			roll.notes = ""
			roll.buttons.notes:SetText("")
			roll.buttons.notes:Hide()
			roll:Hide()
			bdlc:repositionFrames()
		end)
		
		roll.buttons.notes = CreateFrame("EditBox", nil, roll.buttons)
		roll.buttons.notes:SetSize(277, 24)
		roll.buttons.notes:SetPoint("BOTTOMLEFT", roll.buttons, "BOTTOMLEFT", 8, 8)
		roll.buttons.notes:SetMaxLetters(100)
		roll.buttons.notes:IsMultiLine(1)
		roll.buttons.notes:SetTextInsets(6, 2, 2, 2)
		roll.buttons.notes:SetFontObject("BDLC_FONT")
		roll.buttons.notes:SetFrameLevel(8)
		roll.buttons.notes:SetBackdrop({bgFile = "Interface\\Buttons\\WHITE8x8", edgeFile = "Interface\\Buttons\\WHITE8x8", edgeSize = 1})
		roll.buttons.notes:SetBackdropColor(.1,.1,.1,1)
		roll.buttons.notes:SetBackdropBorderColor(0,0,0,1)
		roll.buttons.notes:Hide()
		roll.buttons.notes.okay = CreateFrame("Button", nil, roll.buttons.notes)
		roll.buttons.notes.okay:SetSize(40, 25)
		roll.buttons.notes.okay:SetPoint("LEFT", roll.buttons.notes, "RIGHT", 1, 0)
		roll.buttons.notes.okay:SetText("Okay")
		skinButton(roll.buttons.notes.okay)
		roll.buttons.notes.okay:SetScript("OnClick", function(self)
			self:GetParent():Hide()
			roll.notes = self:GetParent():GetText()
		end)
		roll.buttons.notes:SetScript("OnEnterPressed", function(self, key) roll.buttons.notes.okay:Click() end)
		roll.buttons.notes:SetScript("OnEscapePressed", function(self, key) roll.buttons.notes.okay:Click() end)
		
		bdlc.frames["rolls"][i] = roll
	end
	
	-- Tabs
	lcVoteFrame.tabs = CreateFrame("frame", nil, lcVoteFrame);
	lcVoteFrame.tabs:SetPoint("TOPLEFT", lcVoteFrame, "TOPLEFT", -40, 0)
	lcVoteFrame.tabs:SetPoint("BOTTOMRIGHT", lcVoteFrame, "BOTTOMLEFT", 0, 0)
	-- Number of Items
	for i = 1, 10 do
		lcVoteFrame.tab = CreateFrame('frame', nil, lcVoteFrame)
		lcVoteFrame.tab.active = false
		lcVoteFrame.tab.itemLink = 0
		lcVoteFrame.tab:Hide()
		lcVoteFrame.tab:SetSize(40, 40)
		lcVoteFrame.tab:SetPoint("TOPRIGHT", lcVoteFrame.tabs, "TOPRIGHT", 2, -38*(i-1))
		lcVoteFrame.tab:SetAlpha(0.3)
		lcVoteFrame.tab:EnableMouse(1)
		skinBackdrop(lcVoteFrame.tab, .1,.1,.1,.8);
		lcVoteFrame.tab:SetScript("OnMouseDown", function(self, b)
			if (b == "LeftButton") then
				for tabs = 1, #bdlc.frames["tabs"] do
					bdlc.frames["tabs"][tabs]:SetAlpha(0.3)
					bdlc.frames["tabs"][tabs].table:Hide()
					bdlc.frames["tabs"][tabs].icon:SetDesaturated(true)
				end
				
				self:SetAlpha(1)
				self.table:Show()
				self.icon:SetDesaturated(false)
			end
		end)
		
		lcVoteFrame.tab.icon = lcVoteFrame.tab:CreateTexture(nil, "OVERLAY")
		lcVoteFrame.tab.icon:SetTexCoord(0.08, 0.92, 0.08, 0.92)
		lcVoteFrame.tab.icon:SetDrawLayer('ARTWORK')
		lcVoteFrame.tab.icon:SetTexture(nil)
		lcVoteFrame.tab.icon:SetDesaturated(true)
		lcVoteFrame.tab.icon:SetPoint("TOPLEFT", lcVoteFrame.tab, "TOPLEFT", 2, -2)
		lcVoteFrame.tab.icon:SetPoint("BOTTOMRIGHT", lcVoteFrame.tab, "BOTTOMRIGHT", -2, 2)
		
		--parent frame 
		local vote_table = CreateFrame("Frame", nil, lcVoteFrame.tab) 
		vote_table:SetPoint("TOPLEFT", lcVoteFrame, "TOPLEFT", 10, -100)
		vote_table:SetPoint("BOTTOMRIGHT", lcVoteFrame, "BOTTOMRIGHT", -30, 10)
		vote_table:Hide()
		skinBackdrop(vote_table, .1,.1,.1,.8);
		lcVoteFrame.tab.table = vote_table
		 
		--scrollframe 
		scrollframe = CreateFrame("ScrollFrame", nil, vote_table) 
		scrollframe:SetPoint("TOPLEFT", vote_table, "TOPLEFT", 0, -2) 
		scrollframe:SetPoint("BOTTOMRIGHT", vote_table, "BOTTOMRIGHT", 0, 2) 
		vote_table.scrollframe = scrollframe 
		 
		--scrollbar 
		scrollbar = CreateFrame("Slider", nil, scrollframe, "UIPanelScrollBarTemplate") 
		scrollbar:SetPoint("TOPLEFT", vote_table, "TOPRIGHT", 6, -16) 
		scrollbar:SetPoint("BOTTOMLEFT", vote_table, "BOTTOMRIGHT", 0, 16) 
		scrollbar:SetMinMaxValues(1, 200) 
		scrollbar:SetValueStep(1) 
		scrollbar.scrollStep = 1
		scrollbar:SetValue(0) 
		scrollbar:SetWidth(16) 
		scrollbar:SetScript("OnValueChanged", function (self, value) self:GetParent():SetVerticalScroll(value) end) 
		skinBackdrop(scrollbar, .1,.1,.1,.8);
		vote_table.scrollbar = scrollbar 
		 
		--content frame 
		vote_table.content = CreateFrame("Frame", nil, scrollframe) 
		vote_table.content:SetSize(560, 380) 
		scrollframe:SetScrollChild(vote_table.content)
		
		-- Headers
		vote_table.name_text = vote_table:CreateFontString(nil, "OVERLAY", "BDLC_FONT")
		vote_table.name_text:SetText("Name");
		vote_table.name_text:SetTextColor(1, 1, 1);
		vote_table.name_text:SetPoint("TOPLEFT", vote_table, "TOPLEFT", 10, 16);
		
		vote_table.rank_text = vote_table:CreateFontString(nil, "OVERLAY", "BDLC_FONT")
		vote_table.rank_text:SetText("Rank");
		vote_table.rank_text:SetTextColor(1, 1, 1);
		vote_table.rank_text:SetPoint("TOPLEFT", vote_table, "TOPLEFT", 80, 16);
		
		vote_table.ilvl_text = vote_table:CreateFontString(nil, "OVERLAY", "BDLC_FONT")
		vote_table.ilvl_text:SetText("ilvl");
		vote_table.ilvl_text:SetTextColor(1, 1, 1);
		vote_table.ilvl_text:SetPoint("TOPLEFT", vote_table, "TOPLEFT", 170, 16);
		
		vote_table.ilvl_text = vote_table:CreateFontString(nil, "OVERLAY", "BDLC_FONT")
		vote_table.ilvl_text:SetText("Interest");
		vote_table.ilvl_text:SetTextColor(1, 1, 1);
		vote_table.ilvl_text:SetPoint("TOPLEFT", vote_table, "TOPLEFT", 200, 16);
		
		vote_table.notes_text = vote_table:CreateFontString(nil, "OVERLAY", "BDLC_FONT")
		vote_table.notes_text:SetText("Notes");
		vote_table.notes_text:SetTextColor(1, 1, 1);
		vote_table.notes_text:SetPoint("TOPRIGHT", vote_table, "TOPRIGHT", -250, 16);
		
		vote_table.current_text = vote_table:CreateFontString(nil, "OVERLAY", "BDLC_FONT")
		vote_table.current_text:SetText("Current Gear");
		vote_table.current_text:SetTextColor(1, 1, 1);
		vote_table.current_text:SetPoint("TOPRIGHT", vote_table, "TOPRIGHT", -160, 16);
		
		vote_table.votes_text = vote_table:CreateFontString(nil, "OVERLAY", "BDLC_FONT")
		vote_table.votes_text:SetText("Votes");
		vote_table.votes_text:SetTextColor(1, 1, 1);
		vote_table.votes_text:SetPoint("TOPRIGHT", vote_table, "TOPRIGHT", -100, 16);
		
		vote_table.actions_text = vote_table:CreateFontString(nil, "OVERLAY", "BDLC_FONT")
		vote_table.actions_text:SetText("Vote   Remove");
		vote_table.actions_text:SetTextColor(1, 1, 1);
		vote_table.actions_text:SetPoint("TOPRIGHT", vote_table, "TOPRIGHT", 0, 16);
		
		-- Item icon and such
		vote_table.item = CreateFrame("frame", nil, vote_table)
		vote_table.item:SetPoint("TOPLEFT", vote_table, "TOPLEFT", 10, 64)
		vote_table.item:SetAlpha(1)
		vote_table.item:SetSize(340, 40)

		vote_table.item.itemtext = vote_table.item:CreateFontString(nil, "OVERLAY", "BDLC_FONT_LARGE")
		vote_table.item.itemtext:SetText("Item Name")
		vote_table.item.itemtext:SetPoint("TOPLEFT", vote_table.item, "TOPLEFT", 50, -6)
		
		vote_table.item.num_items = vote_table.item:CreateFontString(nil, "OVERLAY", "BDLC_FONT")
		vote_table.item.num_items:SetTextColor(1,1,1,1);
		vote_table.item.num_items:SetText("x1");
		vote_table.item.num_items:SetPoint("LEFT", vote_table.item.itemtext, "RIGHT", 6, 0)

		vote_table.item.itemdetail = vote_table.item:CreateFontString(nil, "OVERLAY", "BDLC_FONT")
		vote_table.item.itemdetail:SetText("ilvl: ");
		vote_table.item.itemdetail:SetTextColor(1,1,1,.7);
		vote_table.item.itemdetail:SetPoint("BOTTOMLEFT", vote_table.item, "BOTTOMLEFT", 50, 6)

		vote_table.item.icon = CreateFrame("frame", nil, vote_table.item)
		vote_table.item.icon:SetSize(40, 40)
		vote_table.item.icon:SetPoint("TOPLEFT", vote_table.item, "TOPLEFT", 0, 0)
		skinBackdrop(vote_table.item.icon, 0,0,0,.8);

		vote_table.item.icon.tex = vote_table.item.icon:CreateTexture(nil, "OVERLAY")
		vote_table.item.icon.tex:SetTexCoord(0.08, 0.92, 0.08, 0.92)
		vote_table.item.icon.tex:SetDrawLayer('ARTWORK')
		vote_table.item.icon.tex:SetTexture(nil)
		vote_table.item.icon.tex:SetPoint("TOPLEFT", vote_table.item.icon, "TOPLEFT", 2, -2)
		vote_table.item.icon.tex:SetPoint("BOTTOMRIGHT", vote_table.item.icon, "BOTTOMRIGHT", -2, 2)
		
		vote_table.endSession = CreateFrame("Button", nil, vote_table)
		vote_table.endSession:SetSize(100, 25)
		vote_table.endSession:SetPoint("TOPRIGHT", vote_table, "TOPRIGHT", 0, 60)
		vote_table.endSession:SetText("End Session")
		skinButton(vote_table.endSession,false,"red")
		vote_table.endSession:SetScript("OnClick", function()
			SendAddonMessage(bdlc.message_prefix, "endSession><"..bdlc.frames.tabs[i].itemLink, "RAID");
		end)
		
		bdlc.frames.entries[i] = {}
		
		local lastframe = nil
		for e = 1, 40 do
			-- Create entry in table
			local entry = CreateFrame("Button", nil, vote_table.content)
			entry.itemLink = 0
			entry.wantLevel = 0
			entry.rankIndex = 0
			entry.playerName = ""
			entry.notes = ""
			entry.active = false
			entry:SetSize(556, 22)
			if (lastframe) then
				entry:SetPoint("TOPLEFT", lastframe, "BOTTOMLEFT", 0, 2)
			else
				entry:SetPoint("TOPLEFT", vote_table.content, "BOTTOMLEFT", 0, -1)
			end
			entry:SetBackdrop({bgFile = bdlc.config.flat, edgeSize = 0})
			entry:SetBackdropColor(1,1,1,.1)
			entry:Hide()

			entry.name = entry:CreateFontString(nil, "OVERLAY", "BDLC_FONT")
			entry.name:SetText("test");
			entry.name:SetTextColor(1, 1, 1);
			entry.name:SetPoint("LEFT", entry, "LEFT", 10, 0)
			
			entry.award = CreateFrame("Frame",nil, entry)
			entry.award:SetPoint("TOPLEFT", entry.name, "BOTTOMLEFT", 0, -2)
			entry.award:SetSize(100, 42)
			entry.award:Hide()
			skinBackdrop(entry.award, .1,.1,.1,1)
			
			entry.award.text = entry.award:CreateFontString(nil, "OVERLAY", "BDLC_FONT")
			entry.award.text:SetText("Award loot to ?");
			entry.award.text:SetPoint("TOP", entry.award, "TOP", 0, -2)
			
			entry.award.yes = CreateFrame("Button", nil, entry.award)
			entry.award.yes:SetText("Yes")
			entry.award.yes:SetPoint("BOTTOMLEFT", entry.award, "BOTTOMLEFT", 2, 2)
			skinButton(entry.award.yes,false,"blue")
			
			entry.award.no = CreateFrame("Button", nil, entry.award)
			entry.award.no:SetText("No")
			entry.award.no:SetPoint("BOTTOMRIGHT", entry.award, "BOTTOMRIGHT", -2, 2)
			entry.award.no:SetScript("OnClick", function() entry.award:Hide() end)
			skinButton(entry.award.no,false,"red")
			
			entry:SetScript("OnClick", function() 
				if (IsMasterLooter()) then
					if (entry.award:IsShown()) then
						entry.award:Hide()
					else
						entry.award:Show()
						entry.award.text:SetText("Award to "..entry.name:GetText().."?")
						entry.award:SetWidth(entry.award.text:GetWidth()+12)
					end
				else
					entry.award:Hide()
				end
			end)
			
			entry.rank = entry:CreateFontString(nil, "OVERLAY", "BDLC_FONT")
			entry.rank:SetText("rank");
			entry.rank:SetTextColor(1,1,1);
			entry.rank:SetPoint("LEFT", entry, "LEFT", 80, 0)
			
			entry.ilvl = entry:CreateFontString(nil, "OVERLAY", "BDLC_FONT")
			entry.ilvl:SetText(0);
			entry.ilvl:SetTextColor(1,1,1);
			entry.ilvl:SetPoint("LEFT", entry, "LEFT", 166, 0)
			
			entry.interest = entry:CreateFontString(nil, "OVERLAY", "BDLC_FONT")
			entry.interest:SetText("considering...");
			entry.interest:SetTextColor(.5,.5,.5);
			entry.interest:SetPoint("LEFT", entry, "LEFT", 198, 0)
			
			entry.user_notes = CreateFrame('frame', nil, entry)
			entry.user_notes:SetPoint("LEFT", entry, "LEFT", 284, 0)
			entry.user_notes:SetSize(16,16)
			entry.user_notes:Hide()
			entry.user_notes:SetScript("OnEnter", function()
				ShowUIPanel(GameTooltip)
				GameTooltip:SetOwner(UIParent, "ANCHOR_CURSOR")
				GameTooltip:AddLine(entry.notes, 1, 1, 1)
				GameTooltip:Show()
			end)
			entry.user_notes:SetScript("OnLeave", function()
				GameTooltip:Hide()
			end)
			entry.user_notes.tex = entry.user_notes:CreateTexture(nil, "OVERLAY")
			entry.user_notes.tex:SetAllPoints(entry.user_notes)
			entry.user_notes.tex:SetTexture("Interface\\FriendsFrame\\BroadcastIcon")
			
			
			entry.voteUser = CreateFrame("Button", nil, entry)
			entry.voteUser:SetSize(45, 20)
			entry.voteUser:SetPoint("RIGHT", entry, "RIGHT", -38, 0)
			entry.voteUser:SetText("Vote")
			skinButton(entry.voteUser, true, "blue")
			entry.voteUser:Hide()
			entry.voteUser:SetScript("OnClick", function()
				SendAddonMessage(bdlc.message_prefix, "voteForUser><"..local_player.."><"..entry.itemLink.."><"..entry.playerName, "RAID");
			end)
			
			entry.removeUser = CreateFrame("Button", nil, entry)
			entry.removeUser:SetSize(25, 20)
			entry.removeUser:SetPoint("RIGHT", entry, "RIGHT", -7, 0)
			entry.removeUser:SetText("x")
			entry.removeUser:Hide()
			skinButton(entry.removeUser,true,"red")
			entry.removeUser:SetScript("OnClick", function()
				SendAddonMessage(bdlc.message_prefix, "removeUserConsidering><"..entry.itemLink.."><"..entry.playerName, "RAID");
			end)
			
			entry.gear1 = CreateFrame("frame", nil, entry)
			entry.gear1:SetSize(20,20);
			entry.gear1:Hide();
			entry.gear1:SetPoint("RIGHT", entry, "RIGHT", -200, 0);
			skinBackdrop(entry.gear1, 0, 0, 0, 1)
			
			entry.gear1.tex = entry.gear1:CreateTexture(nil, "OVERLAY")
			entry.gear1.tex:SetTexCoord(0.08, 0.92, 0.08, 0.92)
			entry.gear1.tex:SetDrawLayer('ARTWORK')
			entry.gear1.tex:SetTexture(nil)
			entry.gear1.tex:SetPoint("TOPLEFT", entry.gear1, "TOPLEFT", 2, -2)
			entry.gear1.tex:SetPoint("BOTTOMRIGHT", entry.gear1, "BOTTOMRIGHT", -2, 2)
		
			entry.gear2 = CreateFrame("frame", nil, entry)
			entry.gear2:Hide();
			entry.gear2:SetSize(20,20);
			entry.gear2:SetPoint("RIGHT", entry, "RIGHT", -170, 0);
			skinBackdrop(entry.gear2, 0, 0, 0, 1)
			
			entry.gear2.tex = entry.gear2:CreateTexture(nil, "OVERLAY")
			entry.gear2.tex:SetTexCoord(0.08, 0.92, 0.08, 0.92)
			entry.gear2.tex:SetDrawLayer('ARTWORK')
			entry.gear2.tex:SetTexture(nil)
			entry.gear2.tex:SetPoint("TOPLEFT", entry.gear2, "TOPLEFT", 2, -2)
			entry.gear2.tex:SetPoint("BOTTOMRIGHT", entry.gear2, "BOTTOMRIGHT", -2, 2)
			
			entry.votes = CreateFrame('frame', nil, entry)
			entry.votes:SetPoint("RIGHT", entry, "RIGHT", -106, 0);
			entry.votes:SetSize(18, 20)
			entry.votes:SetScript("OnEnter", function()
				
				if (tonumber(entry.votes.text:GetText()) > 0) then
					ShowUIPanel(GameTooltip)
					GameTooltip:SetOwner(UIParent, "ANCHOR_CURSOR")
					
					
					for k, v in pairs(bdlc.loot_council_votes[entry.itemLink][entry.playerName]) do
						local name, server = strsplit("-", k)
						GameTooltip:AddLine(name, 1, 1, 1)
					end	
					
					GameTooltip:Show()
				end

			end)
			entry.votes:SetScript("OnLeave", function()
				GameTooltip:Hide()
			end)
			entry.votes.text = entry.votes:CreateFontString(nil, "OVERLAY", "BDLC_FONT")
			entry.votes.text:SetText("0");
			entry.votes.text:SetTextColor(1, 1, 1);
			entry.votes.text:SetPoint("CENTER", entry.votes, "CENTER", 0, 0)
			
			
			--lcVoteFrame.tab.entries[e] = entry
			lastframe = entry
			bdlc.frames.entries[i][e] = entry
		end
		
		bdlc.frames["tabs"][i] = lcVoteFrame.tab
	end
	bdlc.frames["tabs"][1]:SetAlpha(1)
	bdlc.frames["tabs"][1].table:Show()
	
	debug("created frames")
end